Tag logout

## logout log out a user

name
  logout
xml namespace
  http://moyaproject.com/auth
defined
  /home/will/projects/moya/moya/applications/auth/logic/tags.xml (line 62)

Log out the currently logged in user, or a given user

attributes
name | purpose | type | required?
--- | --- | --- | ---
dst | Destination | Reference | No
lazy | Enable lazy evaluation | boolean | No
user |  | expression | No

inherited attributes
name | purpose | type | required?
--- | --- | --- | ---
if | Conditional expression | expression | No